# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dota_match_metadata.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import dota2.protobufs.base_gcmessages_pb2 as base__gcmessages__pb2
import dota2.protobufs.dota_gcmessages_common_match_management_pb2 as dota__gcmessages__common__match__management__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dota_match_metadata.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x19\x64ota_match_metadata.proto\x1a\x15\x62\x61se_gcmessages.proto\x1a-dota_gcmessages_common_match_management.proto\"|\n\x16\x43\x44OTAMatchMetadataFile\x12\x0f\n\x07version\x18\x01 \x02(\x05\x12\x10\n\x08match_id\x18\x02 \x02(\x04\x12%\n\x08metadata\x18\x03 \x01(\x0b\x32\x13.CDOTAMatchMetadata\x12\x18\n\x10private_metadata\x18\x05 \x01(\x0c\"\xd0\n\n\x12\x43\x44OTAMatchMetadata\x12\'\n\x05teams\x18\x01 \x03(\x0b\x32\x18.CDOTAMatchMetadata.Team\x12/\n\x0citem_rewards\x18\x02 \x03(\x0b\x32\x19.CLobbyTimedRewardDetails\x12\x10\n\x08lobby_id\x18\x03 \x01(\x06\x12\x19\n\x11report_until_time\x18\x04 \x01(\x06\x1a\xb2\t\n\x04Team\x12\x11\n\tdota_team\x18\x01 \x01(\r\x12\x30\n\x07players\x18\x02 \x03(\x0b\x32\x1f.CDOTAMatchMetadata.Team.Player\x12\x18\n\x10graph_experience\x18\x03 \x03(\x02\x12\x19\n\x11graph_gold_earned\x18\x04 \x03(\x02\x12\x17\n\x0fgraph_net_worth\x18\x05 \x03(\x02\x12\x15\n\rcm_first_pick\x18\x06 \x01(\x08\x12\x1c\n\x14\x63m_captain_player_id\x18\x07 \x01(\r\x12\x0f\n\x07\x63m_bans\x18\x08 \x03(\r\x12\x10\n\x08\x63m_picks\x18\t \x03(\r\x12\x12\n\ncm_penalty\x18\n \x01(\r\x1a\x30\n\nPlayerKill\x12\x13\n\x0bvictim_slot\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x1a\x36\n\x0cItemPurchase\x12\x0f\n\x07item_id\x18\x01 \x01(\r\x12\x15\n\rpurchase_time\x18\x02 \x01(\x05\x1av\n\x11InventorySnapshot\x12\x0f\n\x07item_id\x18\x01 \x03(\r\x12\x11\n\tgame_time\x18\x02 \x01(\x05\x12\r\n\x05kills\x18\x03 \x01(\r\x12\x0e\n\x06\x64\x65\x61ths\x18\x04 \x01(\r\x12\x0f\n\x07\x61ssists\x18\x05 \x01(\r\x12\r\n\x05level\x18\x06 \x01(\r\x1a\xc8\x05\n\x06Player\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x18\n\x10\x61\x62ility_upgrades\x18\x02 \x03(\r\x12\x13\n\x0bplayer_slot\x18\x03 \x01(\r\x12)\n\x13\x65quipped_econ_items\x18\x04 \x03(\x0b\x32\x0c.CSOEconItem\x12\x32\n\x05kills\x18\x05 \x03(\x0b\x32#.CDOTAMatchMetadata.Team.PlayerKill\x12\x34\n\x05items\x18\x06 \x03(\x0b\x32%.CDOTAMatchMetadata.Team.ItemPurchase\x12\x15\n\ravg_kills_x16\x18\x07 \x01(\r\x12\x16\n\x0e\x61vg_deaths_x16\x18\x08 \x01(\r\x12\x17\n\x0f\x61vg_assists_x16\x18\t \x01(\r\x12\x13\n\x0b\x61vg_gpm_x16\x18\n \x01(\r\x12\x13\n\x0b\x61vg_xpm_x16\x18\x0b \x01(\r\x12\x16\n\x0e\x62\x65st_kills_x16\x18\x0c \x01(\r\x12\x18\n\x10\x62\x65st_assists_x16\x18\r \x01(\r\x12\x14\n\x0c\x62\x65st_gpm_x16\x18\x0e \x01(\r\x12\x14\n\x0c\x62\x65st_xpm_x16\x18\x0f \x01(\r\x12\x12\n\nwin_streak\x18\x10 \x01(\r\x12\x17\n\x0f\x62\x65st_win_streak\x18\x11 \x01(\r\x12\x13\n\x0b\x66ight_score\x18\x12 \x01(\x02\x12\x12\n\nfarm_score\x18\x13 \x01(\x02\x12\x15\n\rsupport_score\x18\x14 \x01(\x02\x12\x12\n\npush_score\x18\x15 \x01(\x02\x12\x16\n\x0elevel_up_times\x18\x16 \x03(\r\x12\x17\n\x0fgraph_net_worth\x18\x17 \x03(\x02\x12\x46\n\x12inventory_snapshot\x18\x18 \x03(\x0b\x32*.CDOTAMatchMetadata.Team.InventorySnapshot\x12\x1c\n\x14\x61vg_stats_calibrated\x18\x19 \x01(\x08\"\x90\x03\n\x19\x43\x44OTAMatchPrivateMetadata\x12.\n\x05teams\x18\x01 \x03(\x0b\x32\x1f.CDOTAMatchPrivateMetadata.Team\x1a\xc2\x02\n\x04Team\x12\x11\n\tdota_team\x18\x01 \x01(\r\x12\x37\n\x07players\x18\x02 \x03(\x0b\x32&.CDOTAMatchPrivateMetadata.Team.Player\x12;\n\tbuildings\x18\x03 \x03(\x0b\x32(.CDOTAMatchPrivateMetadata.Team.Building\x1aJ\n\x06Player\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x13\n\x0bplayer_slot\x18\x02 \x01(\r\x12\x17\n\x0fposition_stream\x18\x03 \x01(\x0c\x1a\x65\n\x08\x42uilding\x12\x11\n\tunit_name\x18\x01 \x01(\t\x12\x18\n\x10position_quant_x\x18\x02 \x01(\r\x12\x18\n\x10position_quant_y\x18\x03 \x01(\r\x12\x12\n\ndeath_time\x18\x04 \x01(\x02\x42\x03\x90\x01\x00')
  ,
  dependencies=[base__gcmessages__pb2.DESCRIPTOR,dota__gcmessages__common__match__management__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_CDOTAMATCHMETADATAFILE = _descriptor.Descriptor(
  name='CDOTAMatchMetadataFile',
  full_name='CDOTAMatchMetadataFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='CDOTAMatchMetadataFile.version', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CDOTAMatchMetadataFile.match_id', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='CDOTAMatchMetadataFile.metadata', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='private_metadata', full_name='CDOTAMatchMetadataFile.private_metadata', index=3,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=223,
)


_CDOTAMATCHMETADATA_TEAM_PLAYERKILL = _descriptor.Descriptor(
  name='PlayerKill',
  full_name='CDOTAMatchMetadata.Team.PlayerKill',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='victim_slot', full_name='CDOTAMatchMetadata.Team.PlayerKill.victim_slot', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='count', full_name='CDOTAMatchMetadata.Team.PlayerKill.count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=647,
  serialized_end=695,
)

_CDOTAMATCHMETADATA_TEAM_ITEMPURCHASE = _descriptor.Descriptor(
  name='ItemPurchase',
  full_name='CDOTAMatchMetadata.Team.ItemPurchase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CDOTAMatchMetadata.Team.ItemPurchase.item_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='purchase_time', full_name='CDOTAMatchMetadata.Team.ItemPurchase.purchase_time', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=751,
)

_CDOTAMATCHMETADATA_TEAM_INVENTORYSNAPSHOT = _descriptor.Descriptor(
  name='InventorySnapshot',
  full_name='CDOTAMatchMetadata.Team.InventorySnapshot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CDOTAMatchMetadata.Team.InventorySnapshot.item_id', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_time', full_name='CDOTAMatchMetadata.Team.InventorySnapshot.game_time', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kills', full_name='CDOTAMatchMetadata.Team.InventorySnapshot.kills', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deaths', full_name='CDOTAMatchMetadata.Team.InventorySnapshot.deaths', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='assists', full_name='CDOTAMatchMetadata.Team.InventorySnapshot.assists', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level', full_name='CDOTAMatchMetadata.Team.InventorySnapshot.level', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=753,
  serialized_end=871,
)

_CDOTAMATCHMETADATA_TEAM_PLAYER = _descriptor.Descriptor(
  name='Player',
  full_name='CDOTAMatchMetadata.Team.Player',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CDOTAMatchMetadata.Team.Player.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ability_upgrades', full_name='CDOTAMatchMetadata.Team.Player.ability_upgrades', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_slot', full_name='CDOTAMatchMetadata.Team.Player.player_slot', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='equipped_econ_items', full_name='CDOTAMatchMetadata.Team.Player.equipped_econ_items', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kills', full_name='CDOTAMatchMetadata.Team.Player.kills', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='items', full_name='CDOTAMatchMetadata.Team.Player.items', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='avg_kills_x16', full_name='CDOTAMatchMetadata.Team.Player.avg_kills_x16', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='avg_deaths_x16', full_name='CDOTAMatchMetadata.Team.Player.avg_deaths_x16', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='avg_assists_x16', full_name='CDOTAMatchMetadata.Team.Player.avg_assists_x16', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='avg_gpm_x16', full_name='CDOTAMatchMetadata.Team.Player.avg_gpm_x16', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='avg_xpm_x16', full_name='CDOTAMatchMetadata.Team.Player.avg_xpm_x16', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='best_kills_x16', full_name='CDOTAMatchMetadata.Team.Player.best_kills_x16', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='best_assists_x16', full_name='CDOTAMatchMetadata.Team.Player.best_assists_x16', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='best_gpm_x16', full_name='CDOTAMatchMetadata.Team.Player.best_gpm_x16', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='best_xpm_x16', full_name='CDOTAMatchMetadata.Team.Player.best_xpm_x16', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='win_streak', full_name='CDOTAMatchMetadata.Team.Player.win_streak', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='best_win_streak', full_name='CDOTAMatchMetadata.Team.Player.best_win_streak', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fight_score', full_name='CDOTAMatchMetadata.Team.Player.fight_score', index=17,
      number=18, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='farm_score', full_name='CDOTAMatchMetadata.Team.Player.farm_score', index=18,
      number=19, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='support_score', full_name='CDOTAMatchMetadata.Team.Player.support_score', index=19,
      number=20, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='push_score', full_name='CDOTAMatchMetadata.Team.Player.push_score', index=20,
      number=21, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level_up_times', full_name='CDOTAMatchMetadata.Team.Player.level_up_times', index=21,
      number=22, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='graph_net_worth', full_name='CDOTAMatchMetadata.Team.Player.graph_net_worth', index=22,
      number=23, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inventory_snapshot', full_name='CDOTAMatchMetadata.Team.Player.inventory_snapshot', index=23,
      number=24, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='avg_stats_calibrated', full_name='CDOTAMatchMetadata.Team.Player.avg_stats_calibrated', index=24,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=874,
  serialized_end=1586,
)

_CDOTAMATCHMETADATA_TEAM = _descriptor.Descriptor(
  name='Team',
  full_name='CDOTAMatchMetadata.Team',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dota_team', full_name='CDOTAMatchMetadata.Team.dota_team', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players', full_name='CDOTAMatchMetadata.Team.players', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='graph_experience', full_name='CDOTAMatchMetadata.Team.graph_experience', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='graph_gold_earned', full_name='CDOTAMatchMetadata.Team.graph_gold_earned', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='graph_net_worth', full_name='CDOTAMatchMetadata.Team.graph_net_worth', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cm_first_pick', full_name='CDOTAMatchMetadata.Team.cm_first_pick', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cm_captain_player_id', full_name='CDOTAMatchMetadata.Team.cm_captain_player_id', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cm_bans', full_name='CDOTAMatchMetadata.Team.cm_bans', index=7,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cm_picks', full_name='CDOTAMatchMetadata.Team.cm_picks', index=8,
      number=9, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cm_penalty', full_name='CDOTAMatchMetadata.Team.cm_penalty', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CDOTAMATCHMETADATA_TEAM_PLAYERKILL, _CDOTAMATCHMETADATA_TEAM_ITEMPURCHASE, _CDOTAMATCHMETADATA_TEAM_INVENTORYSNAPSHOT, _CDOTAMATCHMETADATA_TEAM_PLAYER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=384,
  serialized_end=1586,
)

_CDOTAMATCHMETADATA = _descriptor.Descriptor(
  name='CDOTAMatchMetadata',
  full_name='CDOTAMatchMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='teams', full_name='CDOTAMatchMetadata.teams', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_rewards', full_name='CDOTAMatchMetadata.item_rewards', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='CDOTAMatchMetadata.lobby_id', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='report_until_time', full_name='CDOTAMatchMetadata.report_until_time', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CDOTAMATCHMETADATA_TEAM, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=1586,
)


_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER = _descriptor.Descriptor(
  name='Player',
  full_name='CDOTAMatchPrivateMetadata.Team.Player',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CDOTAMatchPrivateMetadata.Team.Player.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_slot', full_name='CDOTAMatchPrivateMetadata.Team.Player.player_slot', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position_stream', full_name='CDOTAMatchPrivateMetadata.Team.Player.position_stream', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1812,
  serialized_end=1886,
)

_CDOTAMATCHPRIVATEMETADATA_TEAM_BUILDING = _descriptor.Descriptor(
  name='Building',
  full_name='CDOTAMatchPrivateMetadata.Team.Building',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='unit_name', full_name='CDOTAMatchPrivateMetadata.Team.Building.unit_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position_quant_x', full_name='CDOTAMatchPrivateMetadata.Team.Building.position_quant_x', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position_quant_y', full_name='CDOTAMatchPrivateMetadata.Team.Building.position_quant_y', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='death_time', full_name='CDOTAMatchPrivateMetadata.Team.Building.death_time', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1888,
  serialized_end=1989,
)

_CDOTAMATCHPRIVATEMETADATA_TEAM = _descriptor.Descriptor(
  name='Team',
  full_name='CDOTAMatchPrivateMetadata.Team',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dota_team', full_name='CDOTAMatchPrivateMetadata.Team.dota_team', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players', full_name='CDOTAMatchPrivateMetadata.Team.players', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='buildings', full_name='CDOTAMatchPrivateMetadata.Team.buildings', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER, _CDOTAMATCHPRIVATEMETADATA_TEAM_BUILDING, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1667,
  serialized_end=1989,
)

_CDOTAMATCHPRIVATEMETADATA = _descriptor.Descriptor(
  name='CDOTAMatchPrivateMetadata',
  full_name='CDOTAMatchPrivateMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='teams', full_name='CDOTAMatchPrivateMetadata.teams', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CDOTAMATCHPRIVATEMETADATA_TEAM, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1589,
  serialized_end=1989,
)

_CDOTAMATCHMETADATAFILE.fields_by_name['metadata'].message_type = _CDOTAMATCHMETADATA
_CDOTAMATCHMETADATA_TEAM_PLAYERKILL.containing_type = _CDOTAMATCHMETADATA_TEAM
_CDOTAMATCHMETADATA_TEAM_ITEMPURCHASE.containing_type = _CDOTAMATCHMETADATA_TEAM
_CDOTAMATCHMETADATA_TEAM_INVENTORYSNAPSHOT.containing_type = _CDOTAMATCHMETADATA_TEAM
_CDOTAMATCHMETADATA_TEAM_PLAYER.fields_by_name['equipped_econ_items'].message_type = base__gcmessages__pb2._CSOECONITEM
_CDOTAMATCHMETADATA_TEAM_PLAYER.fields_by_name['kills'].message_type = _CDOTAMATCHMETADATA_TEAM_PLAYERKILL
_CDOTAMATCHMETADATA_TEAM_PLAYER.fields_by_name['items'].message_type = _CDOTAMATCHMETADATA_TEAM_ITEMPURCHASE
_CDOTAMATCHMETADATA_TEAM_PLAYER.fields_by_name['inventory_snapshot'].message_type = _CDOTAMATCHMETADATA_TEAM_INVENTORYSNAPSHOT
_CDOTAMATCHMETADATA_TEAM_PLAYER.containing_type = _CDOTAMATCHMETADATA_TEAM
_CDOTAMATCHMETADATA_TEAM.fields_by_name['players'].message_type = _CDOTAMATCHMETADATA_TEAM_PLAYER
_CDOTAMATCHMETADATA_TEAM.containing_type = _CDOTAMATCHMETADATA
_CDOTAMATCHMETADATA.fields_by_name['teams'].message_type = _CDOTAMATCHMETADATA_TEAM
_CDOTAMATCHMETADATA.fields_by_name['item_rewards'].message_type = dota__gcmessages__common__match__management__pb2._CLOBBYTIMEDREWARDDETAILS
_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER.containing_type = _CDOTAMATCHPRIVATEMETADATA_TEAM
_CDOTAMATCHPRIVATEMETADATA_TEAM_BUILDING.containing_type = _CDOTAMATCHPRIVATEMETADATA_TEAM
_CDOTAMATCHPRIVATEMETADATA_TEAM.fields_by_name['players'].message_type = _CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER
_CDOTAMATCHPRIVATEMETADATA_TEAM.fields_by_name['buildings'].message_type = _CDOTAMATCHPRIVATEMETADATA_TEAM_BUILDING
_CDOTAMATCHPRIVATEMETADATA_TEAM.containing_type = _CDOTAMATCHPRIVATEMETADATA
_CDOTAMATCHPRIVATEMETADATA.fields_by_name['teams'].message_type = _CDOTAMATCHPRIVATEMETADATA_TEAM
DESCRIPTOR.message_types_by_name['CDOTAMatchMetadataFile'] = _CDOTAMATCHMETADATAFILE
DESCRIPTOR.message_types_by_name['CDOTAMatchMetadata'] = _CDOTAMATCHMETADATA
DESCRIPTOR.message_types_by_name['CDOTAMatchPrivateMetadata'] = _CDOTAMATCHPRIVATEMETADATA

CDOTAMatchMetadataFile = _reflection.GeneratedProtocolMessageType('CDOTAMatchMetadataFile', (_message.Message,), dict(
  DESCRIPTOR = _CDOTAMATCHMETADATAFILE,
  __module__ = 'dota_match_metadata_pb2'
  # @@protoc_insertion_point(class_scope:CDOTAMatchMetadataFile)
  ))
_sym_db.RegisterMessage(CDOTAMatchMetadataFile)

CDOTAMatchMetadata = _reflection.GeneratedProtocolMessageType('CDOTAMatchMetadata', (_message.Message,), dict(

  Team = _reflection.GeneratedProtocolMessageType('Team', (_message.Message,), dict(

    PlayerKill = _reflection.GeneratedProtocolMessageType('PlayerKill', (_message.Message,), dict(
      DESCRIPTOR = _CDOTAMATCHMETADATA_TEAM_PLAYERKILL,
      __module__ = 'dota_match_metadata_pb2'
      # @@protoc_insertion_point(class_scope:CDOTAMatchMetadata.Team.PlayerKill)
      ))
    ,

    ItemPurchase = _reflection.GeneratedProtocolMessageType('ItemPurchase', (_message.Message,), dict(
      DESCRIPTOR = _CDOTAMATCHMETADATA_TEAM_ITEMPURCHASE,
      __module__ = 'dota_match_metadata_pb2'
      # @@protoc_insertion_point(class_scope:CDOTAMatchMetadata.Team.ItemPurchase)
      ))
    ,

    InventorySnapshot = _reflection.GeneratedProtocolMessageType('InventorySnapshot', (_message.Message,), dict(
      DESCRIPTOR = _CDOTAMATCHMETADATA_TEAM_INVENTORYSNAPSHOT,
      __module__ = 'dota_match_metadata_pb2'
      # @@protoc_insertion_point(class_scope:CDOTAMatchMetadata.Team.InventorySnapshot)
      ))
    ,

    Player = _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), dict(
      DESCRIPTOR = _CDOTAMATCHMETADATA_TEAM_PLAYER,
      __module__ = 'dota_match_metadata_pb2'
      # @@protoc_insertion_point(class_scope:CDOTAMatchMetadata.Team.Player)
      ))
    ,
    DESCRIPTOR = _CDOTAMATCHMETADATA_TEAM,
    __module__ = 'dota_match_metadata_pb2'
    # @@protoc_insertion_point(class_scope:CDOTAMatchMetadata.Team)
    ))
  ,
  DESCRIPTOR = _CDOTAMATCHMETADATA,
  __module__ = 'dota_match_metadata_pb2'
  # @@protoc_insertion_point(class_scope:CDOTAMatchMetadata)
  ))
_sym_db.RegisterMessage(CDOTAMatchMetadata)
_sym_db.RegisterMessage(CDOTAMatchMetadata.Team)
_sym_db.RegisterMessage(CDOTAMatchMetadata.Team.PlayerKill)
_sym_db.RegisterMessage(CDOTAMatchMetadata.Team.ItemPurchase)
_sym_db.RegisterMessage(CDOTAMatchMetadata.Team.InventorySnapshot)
_sym_db.RegisterMessage(CDOTAMatchMetadata.Team.Player)

CDOTAMatchPrivateMetadata = _reflection.GeneratedProtocolMessageType('CDOTAMatchPrivateMetadata', (_message.Message,), dict(

  Team = _reflection.GeneratedProtocolMessageType('Team', (_message.Message,), dict(

    Player = _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), dict(
      DESCRIPTOR = _CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER,
      __module__ = 'dota_match_metadata_pb2'
      # @@protoc_insertion_point(class_scope:CDOTAMatchPrivateMetadata.Team.Player)
      ))
    ,

    Building = _reflection.GeneratedProtocolMessageType('Building', (_message.Message,), dict(
      DESCRIPTOR = _CDOTAMATCHPRIVATEMETADATA_TEAM_BUILDING,
      __module__ = 'dota_match_metadata_pb2'
      # @@protoc_insertion_point(class_scope:CDOTAMatchPrivateMetadata.Team.Building)
      ))
    ,
    DESCRIPTOR = _CDOTAMATCHPRIVATEMETADATA_TEAM,
    __module__ = 'dota_match_metadata_pb2'
    # @@protoc_insertion_point(class_scope:CDOTAMatchPrivateMetadata.Team)
    ))
  ,
  DESCRIPTOR = _CDOTAMATCHPRIVATEMETADATA,
  __module__ = 'dota_match_metadata_pb2'
  # @@protoc_insertion_point(class_scope:CDOTAMatchPrivateMetadata)
  ))
_sym_db.RegisterMessage(CDOTAMatchPrivateMetadata)
_sym_db.RegisterMessage(CDOTAMatchPrivateMetadata.Team)
_sym_db.RegisterMessage(CDOTAMatchPrivateMetadata.Team.Player)
_sym_db.RegisterMessage(CDOTAMatchPrivateMetadata.Team.Building)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\220\001\000'))
# @@protoc_insertion_point(module_scope)



"""
This module contains various :class:`enum.IntEnum` generated at runtime from protobufs.
Why generate python enums? In short, protobuf's enums aren't great.
:class:`enum.IntEnum` are much more flexible and easy to work with.
"""

import re
from enum import IntEnum
from google.protobuf.internal.enum_type_wrapper import EnumTypeWrapper

_proto_modules = [
    'base_gcmessages_pb2',
    'dota_client_enums_pb2',
    'dota_gcmessages_client_pb2',
    'dota_gcmessages_client_fantasy_pb2',
    'dota_gcmessages_client_match_management_pb2',
    'dota_gcmessages_client_team_pb2',
    'dota_gcmessages_client_tournament_pb2',
    'dota_gcmessages_common_pb2',
    'dota_gcmessages_common_match_management_pb2',
    'dota_gcmessages_msgid_pb2',
    'dota_shared_enums_pb2',
    'gcsdk_gcmessages_pb2',
    'gcsystemmsgs_pb2',
    'steammessages_pb2',
    'econ_gcmessages_pb2',
    'econ_shared_enums_pb2',
]

_proto_module = __import__("dota2.protobufs", globals(), locals(), _proto_modules, 0)

for name in _proto_modules:

    proto = getattr(_proto_module, name)
    gvars = globals()

    for key, value in proto.__dict__.items():
        if not isinstance(value, EnumTypeWrapper):
            continue

        items = {}
        for ikey, ivalue in value.items():
            ikey = re.sub(r'^(k_)?(%s_)?' % key, '', ikey)
            items[ikey] = ivalue

        gvars[key] = IntEnum(key, items)


class ESOType(IntEnum):
    CSOEconItem = 1
    CSOItemRecipe = 5
    CSOEconGameAccountClient = 7
    CSOSelectedItemPreset = 35      # no longer exists in game files
    CSOEconItemPresetInstance = 36  # no longer exists in game files
    CSOEconItemDropRateBonus = 38
    CSOEconItemLeagueViewPass = 39
    CSOEconItemEventTicket = 40
    CSOEconItemTournamentPassport = 42
    CSODOTAGameAccountClient = 2002
    CSODOTAParty = 2003
    CSODOTALobby = 2004
    CSODOTAPartyInvite = 2006
    CSODOTAGameHeroFavorites = 2007
    CSODOTAMapLocationState = 2008
    CMsgDOTATournament = 2009
    CSODOTAPlayerChallenge = 2010
    CSODOTALobbyInvite = 2011


class EServerRegion(IntEnum):
    Unspecified = 0
    USWest = 1
    USEast = 2
    Europe = 3  # EU West
    Korea = 4
    Singapore = 5
    Dubai = 6
    PerfectWorldTelecom = 12            # china
    PerfectWorldTelecomGuangdong = 17   #
    PerfectWorldTelecomZhejiang = 18    #
    PerfectWorldTelecomWuhan = 20       #
    PerfectWorldUnicom = 13             #
    PerfectWorldUnicomTianjin = 25      #
    Stockholm = 8  # Russia
    Brazil = 10
    Austria = 9  # EU East
    Australia = 7
    SouthAfrica = 11
    Chile = 14
    Peru = 15
    India = 16
    Japan = 19


del re, IntEnum, EnumTypeWrapper, _proto_modules, _proto_module, name, proto, gvars, key, value, items, ikey, ivalue

